pub struct ActionTask {Show 13 fields
pub created_at: Option<String>,
pub display_title: Option<String>,
pub event: Option<String>,
pub head_branch: Option<String>,
pub head_sha: Option<String>,
pub id: Option<i64>,
pub name: Option<String>,
pub run_number: Option<i64>,
pub run_started_at: Option<String>,
pub status: Option<String>,
pub updated_at: Option<String>,
pub url: Option<String>,
pub workflow_id: Option<String>,
}Expand description
ActionTask : ActionTask represents a ActionTask
Fields
created_at: Option<String>display_title: Option<String>DisplayTitle is the display title for the workflow run
event: Option<String>Event is the type of event that triggered the workflow
head_branch: Option<String>HeadBranch is the branch that triggered the workflow
head_sha: Option<String>HeadSHA is the commit SHA that triggered the workflow
id: Option<i64>ID is the unique identifier for the action task
name: Option<String>Name is the name of the workflow
run_number: Option<i64>RunNumber is the sequential number of the workflow run
run_started_at: Option<String>status: Option<String>Status indicates the current status of the workflow run
updated_at: Option<String>url: Option<String>URL is the API URL for this workflow run
workflow_id: Option<String>WorkflowID is the identifier of the workflow
Implementations
Sourceimpl ActionTask
impl ActionTask
Sourcepub fn new() -> ActionTask
pub fn new() -> ActionTask
ActionTask represents a ActionTask