Structs
- Apply
Diff Patch File Options - ApplyDiffPatchFileOptions : ApplyDiffPatchFileOptions options for applying a diff patch Note:
authorandcommitterare optional (if only one is given, it will be used for the other, otherwise the authenticated user will be used)