pub struct ApplyDiffPatchFileOptions {
pub author: Option<Box<Identity>>,
pub branch: Option<String>,
pub committer: Option<Box<Identity>>,
pub content: String,
pub dates: Option<Box<CommitDateOptions>>,
pub message: Option<String>,
pub new_branch: Option<String>,
pub signoff: Option<bool>,
}Expand description
ApplyDiffPatchFileOptions : ApplyDiffPatchFileOptions options for applying a diff patch Note: author and committer are optional (if only one is given, it will be used for the other, otherwise the authenticated user will be used)
Fields
branch: Option<String>branch (optional) to base this file from. if not given, the default branch is used
committer: Option<Box<Identity>>content: Stringdates: Option<Box<CommitDateOptions>>message: Option<String>message (optional) for the commit of this file. if not supplied, a default message will be used
new_branch: Option<String>new_branch (optional) will make a new branch from branch before creating the file
signoff: Option<bool>Add a Signed-off-by trailer by the committer at the end of the commit log message.
Implementations
Sourceimpl ApplyDiffPatchFileOptions
impl ApplyDiffPatchFileOptions
Sourcepub fn new(content: String) -> ApplyDiffPatchFileOptions
pub fn new(content: String) -> ApplyDiffPatchFileOptions
ApplyDiffPatchFileOptions options for applying a diff patch Note: author and committer are optional (if only one is given, it will be used for the other, otherwise the authenticated user will be used)