CommitStatus

Struct CommitStatus 

pub struct CommitStatus {
    pub context: Option<String>,
    pub created_at: Option<String>,
    pub creator: Option<Box<User>>,
    pub description: Option<String>,
    pub id: Option<i64>,
    pub status: Option<Status>,
    pub target_url: Option<String>,
    pub updated_at: Option<String>,
    pub url: Option<String>,
}
CommitStatus : CommitStatus holds a single status of a single Commit

Fields

context: Option<String>

Context is the unique context identifier for the status

created_at: Option<String>creator: Option<Box<User>>description: Option<String>

Description provides a brief description of the status

id: Option<i64>

ID is the unique identifier for the commit status

status: Option<Status>

State represents the status state (pending, success, error, failure) pending CommitStatusPending CommitStatusPending is for when the CommitStatus is Pending success CommitStatusSuccess CommitStatusSuccess is for when the CommitStatus is Success error CommitStatusError CommitStatusError is for when the CommitStatus is Error failure CommitStatusFailure CommitStatusFailure is for when the CommitStatus is Failure warning CommitStatusWarning CommitStatusWarning is for when the CommitStatus is Warning skipped CommitStatusSkipped CommitStatusSkipped is for when CommitStatus is Skipped

target_url: Option<String>

TargetURL is the URL to link to for more details

updated_at: Option<String>url: Option<String>

URL is the API URL for this status

Implementations

Source

impl CommitStatus

pub fn new() -> CommitStatus

CommitStatus holds a single status of a single Commit