Module apply_diff_patch_file_options

Module apply_diff_patch_file_options 

Structs

ApplyDiffPatchFileOptions
ApplyDiffPatchFileOptions : ApplyDiffPatchFileOptions options for applying a diff patch Note: author and committer are optional (if only one is given, it will be used for the other, otherwise the authenticated user will be used)